/*  Glimmer - commandbar.h
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _COMMANDBAR_H_
#define _COMMANDBAR_H_

#ifdef __cplusplus
extern "C" {
#endif

#ifdef WITH_PYTHON
#include "declarations.h"
#include "macro-language.h"

void make_command_combo(void);
void command_combo_set_history(GList *history);
gboolean command_combo_add_string(gchar *string);

extern GtkWidget *commandbar;
extern GtkWidget *macro_combo;
extern GtkWidget *macro_entry;
#endif

#ifdef __cplusplus
}
#endif

#endif
